@@ -1,5 +1,6 @@
 from ruletarusa.Revolver import *
 from ruletarusa.Jugador import *
+import pickle
 
 
 class Juego:
@@ -12,6 +13,10 @@ class Juego:
         for i in range(nj):
             self.jugadores.append(Jugador(i + 1))
 
+        inputfile = "juego.dat"
+        binary_file = open(inputfile, mode='wb')
+        pickle.dump(self, binary_file)
+
     def finJuego(self):
         fin_juego = False
 
@@ -35,3 +40,4 @@ class Juego:
         if numero_jugadores < 1 or numero_jugadores > 6:
             numero_jugadores = 6
         return numero_jugadores
+
